@@ -1,15 +1,16 @@
 from .convert.xml import convert_to_xml
-from .convert.xlsx import convert_to_xlsx
+from .convert.xlsx import convert_to_xlsx, write_workbook
 from .convert.csv import convert_to_csv
 from .convert.json import convert_to_json
 from .services.services import Services
 
 
-__version__ = "0.3.12"
+__version__ = "0.3.17"
 __all__ = [
     "convert_to_xml",
     "convert_to_csv",
     "convert_to_xlsx",
     "convert_to_json",
     "Services",
+    "write_workbook",
 ]
