@@ -6,7 +6,7 @@ from .. import convert_to_csv, Services
 
 @click.command(context_settings=dict(max_content_width=200))
 @click.argument("path", type=click.Path(exists=True))
-@click.option("-w", "--workers", default=6, show_default=True, help="amount of workers")
+@click.option("-w", "--workers", default=1, show_default=True, help="amount of workers")
 @click.option(
     "-p",
     "--probability",
@@ -21,19 +21,9 @@ def to_csv(ctx, path, workers, probability):
     # Services available
     spinner = Halo(spinner="dots")
     spinner.start()
-    Services(ctx)
+    services = Services(ctx, check_up=True)
     spinner.succeed(f"Found dir: {path}\n ")
 
-    endpoints = ctx.obj["config"]["endpoints"]
-
     # Conversion
-    convert_to_csv(
-        path,
-        endpoints["extractor"],
-        None if "vat_validation" not in endpoints else endpoints["vat_validation"],
-        None if "validation" not in endpoints else endpoints["validation"],
-        ctx.obj["token"],
-        workers,
-        probability,
-    )
+    convert_to_csv(path, services, workers, path)
     spinner.succeed("Converted invoice(s) to csv")
